@@ -8,7 +8,7 @@ from .log import logger
 HEADER_ATTRS = OrderedDict([
     ('magic', ('I', 2037952207)),
     ('version', ('I', 0)),
-    ('_body_len', ('I', 0)),
+    ('body_len', ('I', 0)),
     ('cmd', ('i', 0)),
     ('ret', ('i', 0)),
     ('reserve_str', ('32s', ''))
@@ -44,13 +44,20 @@ class Box(object):
     def header_format(self):
         return '!' + ''.join(value[0] for value in self.header_attrs.values())
 
+    @property
+    def body_len_key(self):
+        """
+        默认是 body_len，但也支持修改，只要把这个覆盖就可以了
+        """
+        return 'body_len'
+
     @property
     def header_len(self):
         return struct.calcsize(self.header_format)
 
     @property
     def packet_len(self):
-        return self.header_len + self.body_len
+        return self.header_len + getattr(self, self.body_len_key)
 
     @property
     def body(self):
@@ -59,11 +66,7 @@ class Box(object):
     @body.setter
     def body(self, value):
         self._body = value
-        self._body_len = len(self._body)
-
-    @property
-    def body_len(self):
-        return self._body_len
+        setattr(self, self.body_len_key, len(self._body))
 
     def pack(self):
         """
@@ -104,7 +107,7 @@ class Box(object):
                 # raise ValueError('magic not equal. %s != %s' % (magic, HEADER_MAGIC))
                 return -2
 
-        body_len = dict_values.get('_body_len')
+        body_len = dict_values.get(self.body_len_key)
 
         if len(buf) < (body_len + self.header_len):
             # 还要继续收
